==> rent-home-web-1.8-sources.jar: com/ptteng/rent/user/constant/WxConfig.java <==
package com.ptteng.rent.user.constant;

import com.ptteng.rent.user.utils.WeiXinGetUrlPropertiesUtils;

public class WxConfig {

    public static final String ORDER_URL = "https://api.mch.weixin.qq.com/pay/unifiedorder";



    public static final String SECRET = "e8371e148402a4dccce214b080229cc7";


    public static final String notify_url = "http://dev.rent.home.ptteng.com/a/payResult";

    public static final String APPID = WeiXinGetUrlPropertiesUtils.getProperty("wx.appid");
    //开发商户号
    public static final String MCH_ID = WeiXinGetUrlPropertiesUtils.getProperty("wx.mchid");

    public static final String key = WeiXinGetUrlPropertiesUtils.getProperty("wx.api.secret");

    public static String token = WeiXinGetUrlPropertiesUtils.getProperty("weixintoken");

    public static String appID = WeiXinGetUrlPropertiesUtils.getProperty("wx.appid");

    public static String appSecret = WeiXinGetUrlPropertiesUtils.getProperty("appsecret");

    public static String orderPayResult_url = "https://api.mch.weixin.qq.com/pay/orderquery";

    /**
     * 出租人订单结束通知
     */
    public static String ORDER_END = WeiXinGetUrlPropertiesUtils.getProperty("order_end");

    /**
     * 退款申请通知
     */
    public static String REFUND_REQUEST_NOTIFICATION = WeiXinGetUrlPropertiesUtils.getProperty("refund_request_notification");

    /**
     * 新订单通知
     */
    public static String NEW_ORDER = WeiXinGetUrlPropertiesUtils.getProperty("new_order");


    /**
     * 承租人订单结束通知
     */
    public static String LESSEE_ORDER_END = WeiXinGetUrlPropertiesUtils.getProperty("lessee_order_end");

    /**
     * 订单确认通知
     */
    public static String ORDER_CONFIRM = WeiXinGetUrlPropertiesUtils.getProperty("order_confirm");


    /**
     * 下单成功通知
     */
    public static String PAY_ORDER_SUCCESS = WeiXinGetUrlPropertiesUtils.getProperty("pay_order_success");

    /**
     * 图片
     */
    public static final Integer IMAGE = 1;

    /**
     * 视频
     */
    public static final Integer VIDEO = 2;

}

==> rent-home-web-1.9-sources.jar: com/ptteng/rent/user/constant/WxConfig.java <==
package com.ptteng.rent.user.constant;

import com.ptteng.rent.user.utils.WeiXinGetUrlPropertiesUtils;

public class WxConfig {

    public static final String ORDER_URL = "https://api.mch.weixin.qq.com/pay/unifiedorder";



    public static final String SECRET = "e8371e148402a4dccce214b080229cc7";


    public static final String notify_url = WeiXinGetUrlPropertiesUtils.getProperty("notifyUrl");

    public static final String APPID = WeiXinGetUrlPropertiesUtils.getProperty("wx.appid");
    //开发商户号
    public static final String MCH_ID = WeiXinGetUrlPropertiesUtils.getProperty("wx.mchid");

    public static final String key = WeiXinGetUrlPropertiesUtils.getProperty("wx.api.secret");

    public static String token = WeiXinGetUrlPropertiesUtils.getProperty("weixintoken");

    public static String appID = WeiXinGetUrlPropertiesUtils.getProperty("wx.appid");

    public static String appSecret = WeiXinGetUrlPropertiesUtils.getProperty("appsecret");

    public static String orderPayResult_url = "https://api.mch.weixin.qq.com/pay/orderquery";

    /**
     * 出租人订单结束通知
     */
    public static String ORDER_END = WeiXinGetUrlPropertiesUtils.getProperty("order_end");

    /**
     * 退款申请通知
     */
    public static String REFUND_REQUEST_NOTIFICATION = WeiXinGetUrlPropertiesUtils.getProperty("refund_request_notification");

    /**
     * 新订单通知
     */
    public static String NEW_ORDER = WeiXinGetUrlPropertiesUtils.getProperty("new_order");


    /**
     * 承租人订单结束通知
     */
    public static String LESSEE_ORDER_END = WeiXinGetUrlPropertiesUtils.getProperty("lessee_order_end");

    /**
     * 订单确认通知
     */
    public static String ORDER_CONFIRM = WeiXinGetUrlPropertiesUtils.getProperty("order_confirm");


    /**
     * 下单成功通知
     */
    public static String PAY_ORDER_SUCCESS = WeiXinGetUrlPropertiesUtils.getProperty("pay_order_success");

    /**
     * 图片
     */
    public static final Integer IMAGE = 1;

    /**
     * 视频
     */
    public static final Integer VIDEO = 2;

}
